package com.zhentao.pojo;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import java.io.Serializable;
import java.util.Date;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import lombok.Data;
import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.constraints.*;

/**
 * 
 * @TableName app
 */
@TableName(value ="app")
@Data
public class App implements Serializable {
    /**
     * 应用id
     */
//    notnull对数字等进行判断是否为空
//    notblank对string类型判断是否为空
    @TableId(type = IdType.AUTO)
    @NotBlank(message = "应用id不能为空")
    private Integer id;

    /**
     * 签名
     */
    @NotBlank(message = "应用id不能为空")
    private String sign;

    /**
     * 时间戳
     */
//    将序列数转换为json的时候 以tostring的形式 返回
    @NotNull(message = "时间戳不能为空")
    @JsonSerialize(using = ToStringSerializer.class)
    private Date reqtime;

    /**
     * 商品id
     */
    @NotNull(message = "商品id不能为空")
    private Integer goodsid;

    /**
     * 数量
     */
//    限制最小数 和 最大数
    @NotNull(message = "数量不能为空")
    @DecimalMin(value ="0",message ="最数量0")
    private Integer amount;

    /**
     * 价格
     */
    @NotNull(message = "价格不能为空")
    @DecimalMin(value ="0",message ="最小值0")
    @DecimalMax(value="9999",message="最大值9999")
    private Double price;

    /**
     * 手机号
     */
    @NotBlank(message = "手机号不能为空")
//验证手机号码是否符合指定的正则表达式模式
    @Pattern(regexp="^((13[0-9])|(14[0-9])|(15[0-9])|(166)|(17[0-9])|(18[0-9])|(19[0-9]))\\d{8}$",message ="手机号码格式错误")
    private String mobile;
    /**
     * 时间格
     */
//    规范时间格式
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss",timezone = "GMT+8",shape = JsonFormat.Shape.STRING)
    private Date nowdate;

    @TableField(exist = false)
    private static final long serialVersionUID = 1L;

    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        App other = (App) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getSign() == null ? other.getSign() == null : this.getSign().equals(other.getSign()))
            && (this.getReqtime() == null ? other.getReqtime() == null : this.getReqtime().equals(other.getReqtime()))
            && (this.getGoodsid() == null ? other.getGoodsid() == null : this.getGoodsid().equals(other.getGoodsid()))
            && (this.getAmount() == null ? other.getAmount() == null : this.getAmount().equals(other.getAmount()))
            && (this.getPrice() == null ? other.getPrice() == null : this.getPrice().equals(other.getPrice()))
            && (this.getMobile() == null ? other.getMobile() == null : this.getMobile().equals(other.getMobile()))
            && (this.getNowdate() == null ? other.getNowdate() == null : this.getNowdate().equals(other.getNowdate()));
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getSign() == null) ? 0 : getSign().hashCode());
        result = prime * result + ((getReqtime() == null) ? 0 : getReqtime().hashCode());
        result = prime * result + ((getGoodsid() == null) ? 0 : getGoodsid().hashCode());
        result = prime * result + ((getAmount() == null) ? 0 : getAmount().hashCode());
        result = prime * result + ((getPrice() == null) ? 0 : getPrice().hashCode());
        result = prime * result + ((getMobile() == null) ? 0 : getMobile().hashCode());
        result = prime * result + ((getNowdate() == null) ? 0 : getNowdate().hashCode());
        return result;
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", sign=").append(sign);
        sb.append(", reqtime=").append(reqtime);
        sb.append(", goodsid=").append(goodsid);
        sb.append(", amount=").append(amount);
        sb.append(", price=").append(price);
        sb.append(", mobile=").append(mobile);
        sb.append(", nowdate=").append(nowdate);
        sb.append(", serialVersionUID=").append(serialVersionUID);
        sb.append("]");
        return sb.toString();
    }
}