package com.zhentao.service.impl;

import cn.hutool.crypto.digest.DigestUtil;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zhentao.pojo.App;
import com.zhentao.service.AppService;
import com.zhentao.dao.AppMapper;
import com.zhentao.vo.Result;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Date;
import java.util.HashSet;
import java.util.Set;

/**
* @author byf
* @description 针对表【app】的数据库操作Service实现
* @createDate 2025-03-29 10:53:07
*/
@Service
public class AppServiceImpl extends ServiceImpl<AppMapper, App>
    implements AppService{
    @Resource
    AppMapper appMapper;
    static class SynchronizedSetExample {
        private final Set<String> set = new HashSet<String>();

        public synchronized boolean add(String element) {
            return set.add(element);
        }

        public synchronized boolean contains(String element) {
            return set.contains(element);
        }
        // 可以根据需要添加更多方法，如 remove 等，并且都加上 synchronized 关键字
    }
    /**
     * 生成 MD5 签名
     * @param appId 应用 ID
     * @param goodsId 商品 ID
     * @param reqId 请求 ID
     * @param reqTime 请求时间
     * @param appKey 应用密钥
     * @return 生成的 MD5 签名
     */
    public static String generateSignature(String appId, String goodsId, String reqId, String reqTime, String appKey) {
        String input = appId + goodsId + reqId + reqTime + appKey;
        return DigestUtil.md5Hex(input);
    }

    /**
     * 验证签名
     * @param appId 应用 ID
     * @param goodsId 商品 ID
     * @param reqId 请求 ID
     * @param reqTime 请求时间
     * @param appKey 应用密钥
     * @param signature 待验证的签名
     * @return 签名是否有效
     */
    public static boolean verifySignature(String appId, String goodsId, String reqId, String reqTime, String appKey, String signature) {
        String generatedSignature = generateSignature(appId, goodsId, reqId, reqTime, appKey);
        return generatedSignature != null && generatedSignature.equals(signature);
    }
    @Override
    public Result append(String s, String reqId) {
        try {
            // 这里可以进行 reqId 的唯一性验证等操作
            // 示例：假设使用一个简单的静态集合来模拟存储已处理的 reqId
            SynchronizedSetExample synchronizedSet = new SynchronizedSetExample();
            synchronizedSet.add("reqId1");
            if (synchronizedSet.contains(reqId)) {
                return Result.ERROR("重复的 reqId，请求被拒绝", null);
            }
            synchronizedSet.add(reqId);
            // 解析 appJson 为 App 对象，这里使用 FastJSON
            App app = JSONObject.parseObject(s, App.class);
            // 这里可以添加具体的业务逻辑，例如将 app 数据保存到数据库
            // 示例：简单打印信息
            System.out.println("接收到的 App 数据：" + app.toString());
            // 生成签名
            String appId = String.valueOf(app.getId());
            String goodsId = String.valueOf(app.getGoodsid());
//            String reqId = reqId;
            String reqTime = String.valueOf(app.getReqtime());
            String appKey = "AppKey";
            String signature = generateSignature(appId, goodsId, reqId, reqTime, appKey);
            System.out.println("生成的签名: " + signature);
            // 验证签名
            boolean isValid = verifySignature(appId, goodsId, reqId, reqTime, appKey, signature);
            System.out.println("签名是否有效: " + isValid);
            // 假设处理成功
            if(app.getNowdate()==null){
                app.setNowdate(new Date());
            }
            if(app.getReqtime()==null){
                app.setReqtime(new Date());
            }
            int insert = appMapper.insert(app);
            if(insert>0&&signature.equals(app.getSign())){
                return Result.OK( "App 数据追加成功", signature);
            }
            return Result.ERROR("失败",null);
        } catch (Exception e) {
            // 处理异常
            return Result.ERROR("处理 App 数据时发生错误：" + e.getMessage(), null);
        }
    }
}




